@@ -1,4 +1,4 @@
-/* Copyright 2004,2007 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -40,6 +40,8 @@
 /**                                                        **/
 /**   DATES      : # Version 4.0  : from : 21 jan 2004     **/
 /**                                 to   : 21 jan 2004     **/
+/**                # Version 5.0  : from : 23 dec 2007     **/
+/**                                 to   : 16 mar 2008     **/
 /**                                                        **/
 /************************************************************/
 
@@ -49,6 +51,7 @@
 
 #define GMK_MSH
 
+#include "module.h"
 #include "common.h"
 #include "scotch.h"
 #include "gmk_msh.h"
@@ -92,10 +95,9 @@ char *                      argv[])
 
   for (i = 0; i < C_FILENBR; i ++)                /* Set default stream pointers */
     C_fileTab[i].pntr = (C_fileTab[i].mode[0] == 'r') ? stdin : stdout;
-  for (i = 1; i < argc; i ++) {                   /* Loop for all option codes */
-    if ((argv[i][0] != '+') &&                    /* If found a file name      */
-        ((argv[i][0] != '-') || (argv[i][1] == '\0'))) {
-      if (C_fileNum < C_FILEARGNBR)               /* A file name has been given */
+  for (i = 1; i < argc; i ++) {                   /* Loop for all option codes                        */
+    if ((argv[i][0] != '-') || (argv[i][1] == '\0') || (argv[i][1] == '.')) { /* If found a file name */
+      if (C_fileNum < C_FILEARGNBR)               /* File name has been given                         */
         C_fileTab[C_fileNum ++].name = argv[i];
       else {
         errorPrint ("main: too many file names given");
@@ -110,7 +112,7 @@ char *                      argv[])
           return     (0);
         case 'V' :
           fprintf (stderr, "gmk_msh, version %s - F. Pellegrini\n", SCOTCH_VERSION);
-          fprintf (stderr, "Copyright 2004,2007 ENSEIRB, INRIA & CNRS, France\n");
+          fprintf (stderr, "Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS, France\n");
           fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
           return  (0);
         default :
@@ -120,15 +122,7 @@ char *                      argv[])
     }
   }
 
-  for (i = 0; i < C_FILENBR; i ++) {             /* For all file names     */
-    if ((C_fileTab[i].name[0] != '-') ||         /* If not standard stream */
-        (C_fileTab[i].name[1] != '\0')) {
-      if ((C_fileTab[i].pntr = fopen (C_fileTab[i].name, C_fileTab[i].mode)) == NULL) { /* Open the file */
-        errorPrint ("main: cannot open file (%d)", i);
-        return     (1);
-      }
-    }
-  }
+  fileBlockOpen (C_fileTab, C_FILENBR);           /* Open all files */
 
   SCOTCH_meshInit  (&meshdat);
   SCOTCH_graphInit (&grafdat);
@@ -136,25 +130,21 @@ char *                      argv[])
   SCOTCH_meshLoad  (&meshdat, C_filepntrmshinp, -1);
   SCOTCH_meshCheck (&meshdat);
   SCOTCH_meshGraph (&meshdat, &grafdat);
-#ifdef SCOTCH_DEBUG_MAIN1
+#ifdef SCOTCH_DEBUG_ALL
   if (SCOTCH_graphCheck (&grafdat) != 0) {
     errorPrint ("main: bad graph structure");
     return (1);
   }
-#endif /* SCOTCH_DEBUG_MAIN1 */
+#endif /* SCOTCH_DEBUG_ALL */
   SCOTCH_graphSave (&grafdat, C_filepntrgrfout);
 
-#ifdef SCOTCH_DEBUG_MAIN1
+  fileBlockClose (C_fileTab, C_FILENBR);          /* Always close explicitely to end eventual (un)compression tasks */
+
   SCOTCH_graphExit (&grafdat);
-  SCOTCH_meshExit  (&meshgrafdat);
-
-  for (i = 0; i < C_FILENBR; i ++) {             /* For all file names     */
-    if ((C_fileTab[i].name[0] != '-') ||         /* If not standard stream */
-        (C_fileTab[i].name[1] != '\0')) {
-      fclose (C_fileTab[i].pntr);                /* Close the stream */
-    }
-  }
-#endif /* SCOTCH_DEBUG_MAIN1 */
+  SCOTCH_meshExit  (&meshdat);
 
+#ifdef COMMON_PTHREAD
+  pthread_exit ((void *) 0);                      /* Allow potential (un)compression tasks to complete */
+#endif /* COMMON_PTHREAD */
   return (0);
 }
